pub struct StorageEncryption {
key: [u8; 32],
}Expand description
A context for encrypting and decrypting data at rest.
The key is derived from a password and salt using Argon2id.
Fields
key: [u8; 32]Implementations
Sourceimpl StorageEncryption
impl StorageEncryption